import plotly.graph_objects as go
import pytest

from commodplot import messaging


@pytest.mark.skip()
def test_compose_and_send_report():
    fig = go.Figure(
        data=[go.Bar(x=[1, 2, 3], y=[1, 3, 2])],
        layout=go.Layout(
            title=go.layout.Title(text="A Figure Specified By A Graph Object")
        )
    )

    subject = 'test_email'
    content = '''
        <html>
            <body>
                <h1 style="text-align: center;">Simple Data Report</h1>
                <p>Here could be a short description of the data.</p>
                <p><img src="cid:0"></p>
            </body>
        </html>'
        '''

    img = fig.to_image(width=1200, height=350, engine='kaleido')
    images = {'0': img}
    sender = 'testcommodplot@mailinator.com'
    messaging.compose_and_send_report(subject=subject, content=content, images=images, sender_email=sender,
                                      receiver_email=sender)


@pytest.mark.skip()
def test_compose_jinja_report():
    fig = go.Figure(
        data=[go.Bar(x=[1, 2, 3], y=[1, 3, 2])],
        layout=go.Layout(
            title=go.layout.Title(text="A Figure Specified By A Graph Object")
        )
    )

    data = {'name': 'test', 'fig1': fig}

    subject = 'test_email'
    sender = 'testcommodplot@mailinator.com'
    messaging.compose_and_send_jinja_report(subject=subject, data=data, template='test_report.html',
                                            package_loader_name='commodplot', sender_email=sender,
                                            receiver_email=sender)



import itertools

import cufflinks as cf
import pandas as pd
import plotly as py
import plotly.graph_objects as go
from commodutil import dates
from commodutil import transforms
from plotly.subplots import make_subplots

from commodplot import commodplottrace as cptr
from commodplot import commodplotutil as cpu

preset_margins = {'l': 0, 'r': 0, 't': 40, 'b': 0}


def seas_line_plot(df, fwd=None, **kwargs):
    """
     Given a DataFrame produce a seasonal line plot (x-axis - Jan-Dec, y-axis Yearly lines)
     Can overlay a forward curve on top of this
    """

    fig = go.Figure()
    traces = cptr.seas_plot_traces(df, fwd, **kwargs)
    if 'shaded_range' in traces:
        for trace in traces['shaded_range']:
            fig.add_trace(trace)

    if 'average_line' in traces:
        fig.add_trace(traces['average_line'])

    if 'hist' in traces:
        for trace in traces['hist']:
            fig.add_trace(trace)

    if 'fwd' in traces:
        for trace in traces['fwd']:
            fig.add_trace(trace)

    fig.layout.xaxis.tickvals = pd.date_range(start=str(dates.curyear), periods=12, freq='MS')

    title = cpu.gen_title(df, **kwargs)
    legend = go.layout.Legend(font=dict(size=10), traceorder='reversed')
    yaxis_title = kwargs.get('yaxis_title', None)
    hovermode = kwargs.get('hovermode', 'x')
    fig.update_layout(title=title, title_x=0.01, xaxis_tickformat='%b', yaxis_title=yaxis_title, legend=legend,
                      hovermode=hovermode, margin=preset_margins)

    return fig


def seas_line_subplot(rows, cols, df, fwd=None, **kwargs):
    """
    Generate a plot with multiple seasonal subplots.
    :param rows:
    :param cols:
    :param dfs:
    :param fwds:
    :param kwargs:
    :return:
    """
    fig = make_subplots(
        cols=cols,
        rows=rows,
        specs=[[{'type': 'scatter'} for x in range(0, cols)] for y in range(0, rows)],
        subplot_titles=kwargs.get('subplot_titles', None)
    )

    chartcount = 0
    for row in range(1, rows + 1):
        for col in range(1, cols + 1):
            # print(row, col)
            if chartcount > len(df):
                chartcount += 1
                continue

            dfx = df[df.columns[chartcount]]
            fwdx = None
            if fwd is not None and len(fwd) > chartcount:
                fwdx = fwd[fwd.columns[chartcount]]

            showlegend = True if chartcount == 0 else False

            traces = cptr.seas_plot_traces(dfx, fwd=fwdx, showlegend=showlegend, **kwargs)

            for trace_set in ['shaded_range', 'hist', 'fwd']:
                if trace_set in traces:
                    for trace in traces[trace_set]:
                        fig.add_trace(trace, row=row, col=col)

            chartcount += 1

    legend = go.layout.Legend(font=dict(size=10))
    fig.update_xaxes(tickvals=pd.date_range(start=str(dates.curyear), periods=12, freq='MS'), tickformat='%b')
    title = kwargs.get('title', '')
    fig.update_layout(title=title, title_x=0.01, xaxis_tickformat='%b', legend=legend, margin=preset_margins)
    return fig


def seas_box_plot(hist, fwd=None, **kwargs):
    hist = transforms.monthly_mean(hist)
    hist = hist.T

    data = []
    monthstr = {x.month: x.strftime('%b') for x in pd.date_range(start='2018', freq='M', periods=12)}
    for x in hist.columns:
        trace = go.Box(
            name=monthstr[x],
            y=hist[x]
        )
        data.append(trace)

    fwdl = transforms.seasonailse(fwd)
    fwdl.index = fwdl.index.strftime('%b')
    for col in fwdl.columns:
        ser = fwdl[col].copy()
        trace = go.Scatter(
            name=col,
            x=ser.index,
            y=ser,
            line=dict(color=cptr.get_year_line_col(col), dash='dot')
        )
        data.append(trace)

    fig = go.Figure(data=data)
    title = kwargs.get('title', '')
    fig.update_layout(title=title, title_x=0.01, margin=preset_margins)

    return fig


def seas_table_plot(hist, fwd=None):
    df = cpu.seas_table(hist, fwd)

    colsh = list(df.columns)
    colsh.insert(0, 'Period')

    cols = [df[x] for x in df]
    cols.insert(0, list(df.index))
    fillcolor = ['lavender'] * 12
    fillcolor.extend(['aquamarine'] * 4)
    fillcolor.extend(['darkturquoise'] * 2)
    fillcolor.append('dodgerblue')

    figm = go.Figure(data=[go.Table(
        header=dict(values=colsh, fill_color='paleturquoise', align='left'),
        cells=dict(values=cols, fill_color=[fillcolor], align='left'))
    ])
    return figm


def table_plot(df, **kwargs):
    row_even_colour = kwargs.get('row_even_colour', 'lightgrey')
    row_odd_color = kwargs.get('row_odd_colour', 'white')

    # include index col as part of plot
    indexname = '' if df.index.name is None else df.index.name
    colheaders = [indexname] + list(df.columns)
    headerfill = ['white' if x == '' else 'grey' for x in colheaders]

    cols = [df[x] for x in df.columns]
    # apply red/green to formatted_cols
    fcols = kwargs.get('formatted_cols', [])
    font_color = [['red' if str(y).startswith('-') else 'green' for y in df[x]] if x in fcols else 'black' for x in
                  colheaders]

    if isinstance(df.index, pd.DatetimeIndex):  # if index is datetime, format dates
        df.index = df.index.map(lambda x: x.strftime('%d-%m-%Y'), 1)
    cols.insert(0, df.index)

    fig = go.Figure(data=[go.Table(
        header=dict(values=colheaders, fill_color=headerfill, align='center', font=dict(color='white', size=12)),
        cells=dict(values=cols,
                   line=dict(color='#506784'),
                   fill_color=[[row_odd_color, row_even_colour] * len(df)],
                   align='right',
                   font_color=font_color,
                   ))
    ])
    return fig


def forward_history_plot(df, title=None, **kwargs):
    """
     Given a dataframe of a curve's pricing history, plot a line chart showing how it has evolved over time
    """
    df = df.rename(columns={x: pd.to_datetime(x) for x in df.columns})
    df = df[sorted(list(df.columns), reverse=True)]  # have latest column first
    df = df.rename(
        columns={x: cpu.format_date_col(x, '%d-%b-%y') for x in df.columns})  # make nice labels for legend eg 05-Dec

    colseq = py.colors.sequential.Aggrnyl
    text = df.index.strftime('%b-%y')

    fig = go.Figure()
    colcount = 0
    for col in df.columns:
        color = colseq[colcount] if colcount < len(colseq) else colseq[-1]
        fig.add_trace(
            go.Scatter(x=df.index, y=df[col], hoverinfo='y', name=str(col), line=dict(color=color),
                       hovertemplate=cptr.hovertemplate_default, text=text))

        colcount = colcount + 1

    fig['data'][0]['line']['width'] = 2.2  # make latest line thicker
    legend = go.layout.Legend(font=dict(size=10))
    yaxis_title = kwargs.get('yaxis_title', None)
    fig.update_layout(title=title, title_x=0.01, xaxis_tickformat='%b-%y', yaxis_title=yaxis_title, legend=legend, margin=preset_margins)
    return fig


def bar_line_plot(df, linecol='Total', **kwargs):
    """
    Give a dataframe, make a stacked bar chart along with overlaying line chart.
    """
    if linecol not in df:
        df[linecol] = df.sum(1, skipna=False)

    barcols = [x for x in df.columns if linecol not in x]
    barspecs = {'kind': 'bar', 'barmode': 'relative', 'title': 'd', 'columns': barcols}
    linespecs = {'kind': 'scatter', 'columns': linecol, 'color': 'black'}

    fig = cf.tools.figures(df, [barspecs, linespecs])  # returns dict
    fig = go.Figure(fig)
    yaxis_title = kwargs.get('yaxis_title', None)
    yaxis_range = kwargs.get('yaxis_range', None)
    title = kwargs.get('title', None)
    fig.update_layout(title=title, title_x=0.01, xaxis_title='Date', yaxis_title=yaxis_title, margin=preset_margins)
    if yaxis_range is not None:
        fig.update_layout(yaxis=dict(range=yaxis_range))
    return fig


def diff_plot(df, **kwargs):
    """
    Given a dataframe, plot each column as line plot with a subplot below
    showing differences between each column.
    :param df:
    :param kwargs:
    :return:
    """
    # calculate difference between each column
    for comb in (itertools.combinations(df.columns, 2)):
        df['%s-%s' % (comb[0], comb[1])] = df[comb[0]] - df[comb[1]]

    barcols = [x for x in df.columns if '-' in x]
    linecols = [x for x in df.columns if '-' not in x]

    fig = make_subplots(rows=2, cols=1, row_heights=[0.8, 0.2], shared_xaxes=True, vertical_spacing=0.02)
    for col in linecols:
        fig.add_trace(go.Scatter(x=df.index, y=df[col], name=col))

    for col in barcols:
        fig.add_trace(go.Bar(x=df.index, y=df[col], name=col), row=2, col=1)

    title = kwargs.get('title', '')
    fig.update_layout(title_text=title, title_x=0.01, margin=preset_margins)
    return fig


def reindex_year_line_plot(df, **kwargs):
    """
    Given a dataframe of timeseries, reindex years and produce line plot
    :param df:
    :return:
    """
    fig = go.Figure()
    dft = transforms.reindex_year(df)
    colsel = cpu.reindex_year_df_rel_col(dft)

    traces = cptr.reindex_plot_traces(dft, current_select_year=colsel, **kwargs)

    if 'shaded_range' in traces:
        for trace in traces['shaded_range']:
            fig.add_trace(trace)

    if 'hist' in traces:
        for trace in traces['hist']:
            fig.add_trace(trace)

    kwargs['title_postfix'] = colsel
    title = cpu.gen_title(df[colsel], title_prefix=colsel, **kwargs)

    legend = go.layout.Legend(font=dict(size=10))
    yaxis_title = kwargs.get('yaxis_title', None)
    fig.update_layout(title=title, title_x=0.01, xaxis_tickformat='%b-%y', yaxis_title=yaxis_title, legend=legend, margin=preset_margins)
    # zoom into last 3 years
    fig.update_xaxes(type="date",
                     range=[dft.tail(365 * 3).index[0].strftime('%Y-%m-%d'), dft.index[-1].strftime('%Y-%m-%d')])

    return fig


def candle_chart(df, **kwargs):
    fig = go.Figure(data=[go.Candlestick(x=df.index,
                                         open=df['Open'],
                                         high=df['High'],
                                         low=df['Low'],
                                         close=df['Close'])])

    title = cpu.gen_title(df['Close'], **kwargs)
    fig.update_layout(title=title)
    return fig


def stacked_area_chart(df, **kwargs):
    fig = go.Figure()
    group = kwargs.get('stackgroup', 'stackgroup')

    for col in df.columns:
        fig.add_trace(go.Scatter(x=df.index, y=df[col], name=col, stackgroup=group))

    fig.update_layout(title=kwargs.get('title', ''))
    return fig


def bar_chart(df, **kwargs):
    fig = go.Figure()

    for col in df.columns:
        fig.add_trace(go.Bar(x=df.index, y=df[col], name=col))

    hovermode = kwargs.get('hovermode', 'x')
    fig.update_layout(title=kwargs.get('title', ''), hovermode=hovermode)
    barmode = kwargs.get('barmode', None)
    if barmode:
        fig.update_layout(barmode=barmode)

    return fig


def reindex_year_line_subplot(rows, cols, dfs, **kwargs):
    fig = make_subplots(
        cols=cols,
        rows=rows,
        specs=[[{'type': 'scatter'} for x in range(0, cols)] for y in range(0, rows)],
        subplot_titles=kwargs.get('subplot_titles', None),
        shared_xaxes=False,
    )

    chartcount = 0
    for row in range(1, rows + 1):
        for col in range(1, cols + 1):
            # print(row, col)
            if chartcount > len(dfs):
                chartcount += 1
                continue
            showlegend = True if chartcount == 0 else False

            dfx = dfs[chartcount]
            dft = transforms.reindex_year(dfx)
            colsel = cpu.reindex_year_df_rel_col(dft)
            traces = cptr.reindex_plot_traces(dft, current_select_year=colsel, showlegend=showlegend, **kwargs)
            for trace_set in ['shaded_range', 'hist']:
                if trace_set in traces:
                    for trace in traces[trace_set]:
                        fig.add_trace(trace, row=row, col=col)

            chartcount += 1

    legend = go.layout.Legend(font=dict(size=10))
    yaxis_title = kwargs.get('yaxis_title', None)
    hovermode = kwargs.get('hovermode', 'closest')
    title = kwargs.get('title', '')
    fig.update_layout(title=title, title_x=0.01, xaxis_tickformat='%b-%y', yaxis_title=yaxis_title, legend=legend,
                      hovermode=hovermode, margin=preset_margins)

    fig.update_xaxes(type="date")

    return fig


def line_plot(df, fwd=None, **kwargs):
    fig = go.Figure()
    res = cptr.line_plot_traces(df, fwd, **kwargs)
    for trace in res:
        fig.add_trace(trace)

    title = cpu.gen_title(df, inc_change_sum=False, **kwargs)
    legend = go.layout.Legend(font=dict(size=10))
    yaxis_title = kwargs.get('yaxis_title', None)
    hovermode = kwargs.get('hovermode', 'closest')
    fig.update_layout(title=title, title_x=0.01, yaxis_title=yaxis_title, legend=legend, hovermode=hovermode)
    return fig



import pandas as pd

table_style = [
    dict(selector="tr:hover",
         props=[("background", "#D6EEEE")]),
    dict(selector="th", props=[("color", "#fff"),
                               ("border", "1px solid #eee"),
                               ("padding", "12px 35px"),
                               ("border-collapse", "collapse"),
                               ("background", "#1D4477"),
                               ("font-size", "18px")
                               ]),
    dict(selector="td", props=[
        ("border", "1px solid #eee"),
        ("padding", "10px 20px"),
        ("border-collapse", "collapse"),
        ("font-size", "15px")
    ]),
    dict(selector="table", props=[
        ("font-family", 'Helvetica'),
        ("margin", "25px auto"),
        ("border-collapse", "collapse"),
        ("border", "1px solid #eee"),
        ("border-bottom", "2px solid #00cccc"),
    ]),
    dict(selector="caption", props=[("caption-side", "bottom")]),
    dict(selector="tr:nth-child(even)", props=[
        ("background-color", "#f2f2f2"),
    ]),
]


def color_accounting(val):
    """
    Takes a scalar and returns a string with
    the css property `'color: red'` for negative
    strings, green otherwise.
    """
    color = 'red' if val < 0 else 'green'
    return 'color: %s' % color

def generate_table(df: pd.DataFrame, precision:int=None, accounting_col_columns: list = None):
    if accounting_col_columns:
        res = (df.style.applymap(color_accounting, subset=accounting_col_columns).set_table_styles(table_style))
    else:
        res = df.style.set_table_styles(table_style)

    if precision:
        res = res.format(precision=2)
    return res.to_html()



import unittest

import cufflinks as cf
import pandas as pd

from commodplot import commodplotutil as cpu


class TestCommodPlotUtil(unittest.TestCase):

    def test_delta_summary_str(self):
        df = cf.datagen.lines(2, 1000)
        col = df.columns[0]

        m1 = df.iloc[-1, 0]
        m2 = df.iloc[-2, 0]
        diff = m1 - m2
        res = cpu.delta_summary_str(df)

        self.assertIn(str(m1.round(2)), res)
        self.assertIn(str(diff.round(2)), res)

    def test_gen_title(self):
        df = pd.DataFrame([1, 2, 3], columns=['Test'])

        res = cpu.gen_title(df, title=None)
        self.assertTrue(res.startswith('3'))

        res = cpu.gen_title(df, title='TTitle')
        self.assertTrue(res.startswith('TTitle'))
        self.assertTrue(res.endswith('+1'))

        res = cpu.gen_title(df, title='TTitle', title_postfix='post')
        self.assertTrue(res.startswith('TTitle  post:'))
        self.assertTrue(res.endswith('+1'))


if __name__ == '__main__':
    unittest.main()



import os
import unittest

import pandas as pd
import plotly.graph_objects as go
from commodutil import forwards

from commodplot import commodplot


class TestCommodplot(unittest.TestCase):

    def test_seas_line_plot(self):
        dirname, filename = os.path.split(os.path.abspath(__file__))
        cl = pd.read_csv(os.path.join(dirname, 'test_cl.csv'), index_col=0, parse_dates=True, dayfirst=True)
        cl = cl.dropna(how='all', axis=1)
        fwd = pd.DataFrame([50 for x in range(12)], index=pd.date_range('2021-01-01', periods=12, freq='MS'))

        res = commodplot.seas_line_plot(cl[cl.columns[-1]], fwd=fwd, shaded_range=5, visible_line_years=3,
                                        average_line=5)
        self.assertTrue(isinstance(res, go.Figure))

        shaded_range_max = [x for x in res.data if 'Max' in x['name']]
        self.assertEqual(len(shaded_range_max), 1)
        shaded_range_min = [x for x in res.data if 'Min' in x['name']]
        self.assertEqual(len(shaded_range_min), 1)

        solid_line = [x for x in res.data if x['name'] == '2020']
        self.assertEqual(solid_line[0].hoverinfo, 'y')

        dot_line = [x for x in res.data if x['name'] == '2021']
        self.assertEqual(dot_line[0].line.dash, 'dot')

    def test_seas_line_subplot(self):
        dr = pd.date_range(start='2015', end='2020-12-31', freq='B')
        data = {'A': [10 for x in dr], 'B': [20 for x in dr], 'C': [30 for x in dr], 'D': [10 for x in dr]}
        df = pd.DataFrame(data, index=dr)
        dr = pd.date_range('2021-01-01', periods=12, freq='MS')
        data = {'A': [10 for x in dr], 'B': [20 for x in dr], 'C': [30 for x in dr], 'D': [10 for x in dr]}
        fwd = pd.DataFrame(data, index=dr)

        res = commodplot.seas_line_subplot(2, 2, df, fwd=fwd, subplot_titles=['1', '2', '3', '4'], shaded_range=5)
        self.assertTrue(isinstance(res, go.Figure))
        self.assertEqual(4, [x.name for x in res.data].count('2020'))

    def test_reindex_year_line_plot(self):
        dirname, filename = os.path.split(os.path.abspath(__file__))
        cl = pd.read_csv(os.path.join(dirname, 'test_cl.csv'), index_col=0, parse_dates=True, dayfirst=True)
        cl = cl.dropna(how='all', axis=1)
        cl = cl.rename(columns={x: pd.to_datetime(forwards.convert_contract_to_date(x)) for x in cl.columns})

        sp = forwards.time_spreads(cl, 12, 12)

        res = commodplot.reindex_year_line_plot(sp)
        self.assertTrue(isinstance(res, go.Figure))

    def test_fwd_hist_plot(self):
        dirname, filename = os.path.split(os.path.abspath(__file__))
        cl = pd.read_csv(os.path.join(dirname, 'test_cl_fwd.csv'), index_col=0, parse_dates=True, dayfirst=True)
        res = commodplot.forward_history_plot(cl)
        self.assertTrue(isinstance(res, go.Figure))

    def test_candle_chart(self):
        dirname, filename = os.path.split(os.path.abspath(__file__))
        cl = pd.read_csv(os.path.join(dirname, 'test_cl_chlo.csv'), index_col=0, parse_dates=True, dayfirst=True)

        res = commodplot.candle_chart(cl)
        self.assertTrue(isinstance(res, go.Figure))

    def test_stack_area_chart(self):
        dirname, filename = os.path.split(os.path.abspath(__file__))
        cl = pd.read_csv(os.path.join(dirname, 'test_cl_chlo.csv'), index_col=0, parse_dates=True, dayfirst=True)

        res = commodplot.stacked_area_chart(cl)
        self.assertTrue(isinstance(res, go.Figure))

    def test_stack_bar_chart(self):
        dirname, filename = os.path.split(os.path.abspath(__file__))
        cl = pd.read_csv(os.path.join(dirname, 'test_cl_chlo.csv'), index_col=0, parse_dates=True, dayfirst=True)

        res = commodplot.bar_chart(cl, barmode='stack')
        self.assertTrue(isinstance(res, go.Figure))

    def test_reindex_year_line_subplot(self):
        dr = pd.date_range(start='2015', end='2020-12-31', freq='B')
        data = {'Q1 2019': [10 for x in dr], 2020: [20 for x in dr], 2021: [30 for x in dr], 2022: [10 for x in dr]}
        df = pd.DataFrame(data, index=dr)
        dfs = [df for x in range(1, 5)]

        res = commodplot.reindex_year_line_subplot(2, 2, dfs, subplot_titles=['1', '2', '3', '4'])
        self.assertTrue(isinstance(res, go.Figure))

    def test_seas_box_plot(self):
        dirname, filename = os.path.split(os.path.abspath(__file__))
        cl = pd.read_csv(os.path.join(dirname, 'test_cl.csv'), index_col=0, parse_dates=True, dayfirst=True)
        cl = cl.dropna(how='all', axis=1)
        fwd = cl[cl.columns[-1]].resample('MS').mean()

        res = commodplot.seas_box_plot(cl[cl.columns[-1]], fwd)
        self.assertTrue(isinstance(res, go.Figure))

    def test_table_plot(self):
        dirname, filename = os.path.split(os.path.abspath(__file__))
        cl = pd.read_csv(os.path.join(dirname, 'test_cl.csv'), index_col=0, parse_dates=True, dayfirst=True)
        cl = cl.dropna(how='all', axis=1)

        res = commodplot.table_plot(cl, formatted_cols=['CL_2020F'])
        self.assertTrue(isinstance(res, go.Figure))

    def test_seas_table(self):
        dirname, filename = os.path.split(os.path.abspath(__file__))
        cl = pd.read_csv(os.path.join(dirname, 'test_cl.csv'), index_col=0, parse_dates=True, dayfirst=True)
        cl = cl.dropna(how='all', axis=1)
        fwd = cl[cl.columns[-1]].resample('MS').mean()

        res = commodplot.seas_table_plot(cl[cl.columns[-1]], fwd)
        self.assertTrue(isinstance(res, go.Figure))

    def test_diff_plot(self):
        dirname, filename = os.path.split(os.path.abspath(__file__))
        cl = pd.read_csv(os.path.join(dirname, 'test_cl.csv'), index_col=0, parse_dates=True, dayfirst=True)
        cl = cl.dropna(how='all', axis=1)[['CL_2020F', 'CL_2020G']]

        res = commodplot.diff_plot(cl, title='Test')
        self.assertTrue(isinstance(res, go.Figure))

    def test_line_plot(self):
        dirname, filename = os.path.split(os.path.abspath(__file__))
        cl = pd.read_csv(os.path.join(dirname, 'test_cl.csv'), index_col=0, parse_dates=True, dayfirst=True)
        cl = cl.dropna(how='all', axis=1)[['CL_2019F', 'CL_2020G']]
        fwd = pd.DataFrame([[50 for x in range(2)]], index=pd.date_range('2021-01-01', periods=12, freq='MS'),
                           columns=['CL_2019F', 'CL_2020G'])

        res = commodplot.line_plot(cl, fwd=fwd, title='Test')
        self.assertTrue(isinstance(res, go.Figure))

    def test_line_plot2(self):
        dirname, filename = os.path.split(os.path.abspath(__file__))
        cl = pd.read_csv(os.path.join(dirname, 'test_cl.csv'), index_col=0, parse_dates=True, dayfirst=True)
        cl = cl.dropna(how='all', axis=1)[['CL_2020F', 'CL_2020G']]
        cl = cl.rename(columns={'CL_2020F': 'A', 'CL_2020G': 'B'})
        fwd = pd.DataFrame([[50 for x in range(2)]], index=pd.date_range('2021-01-01', periods=12, freq='MS'),
                           columns=['A', 'B'])

        res = commodplot.line_plot(cl, fwd=fwd, title='Test')
        self.assertTrue(isinstance(res, go.Figure))


if __name__ == '__main__':
    unittest.main()



import unittest

import pandas as pd

from commodplot import commodplottable as cpt


class TestCommodplotTable(unittest.TestCase):

    def test_generate_table(self):
        df = pd.DataFrame(
            [[1, 2, 3, 4], [5, 6, 7, 8], [3, -5, 6, 7]],
            columns=['Foo', 'Bar', 'Buzz', 'Fuzz'],
            index=['First', 'Second', 'Third'],
        )
        res = cpt.generate_table(df, accounting_col_columns=['Bar'])
        self.assertIn('<style type="text/css">', res)


if __name__ == '__main__':
    unittest.main()



import os
import unittest

import plotly.express as px
import plotly.graph_objects as go

from commodplot import jinjautils


class TestCommodPlotUtil(unittest.TestCase):

    def test_convert_dict_plotly_fig_html_div(self):
        df = px.data.gapminder().query("country=='Canada'")
        fig = px.line(df, x="year", y="lifeExp", title='Life expectancy in Canada')

        data = {}
        data['ch1'] = fig
        data['el'] = 1
        data['innerd'] = {}
        data['innerd']['ch2'] = fig

        res = jinjautils.convert_dict_plotly_fig_html_div(data)
        self.assertTrue(isinstance(res['ch1'], str))
        self.assertTrue(isinstance(res['innerd']['ch2'], str))

    def test_render_html_to_file(self):
        dirname, filename = os.path.split(os.path.abspath(__file__))
        test_out_loc = os.path.join(dirname, 'test.html')
        if os.path.exists(test_out_loc):
            os.remove(test_out_loc)

        fig = go.Figure(
            data=[go.Bar(x=[1, 2, 3], y=[1, 3, 2])],
            layout=go.Layout(
                title=go.layout.Title(text="A Figure Specified By A Graph Object")
            )
        )

        data = {'name': 'test', 'fig1' : fig}

        jinjautils.render_html(data, template='test_report.html', filename='test.html', package_loader_name='commodplot')

        self.assertTrue(test_out_loc)
        if os.path.exists(test_out_loc):
            os.remove(test_out_loc)


if __name__ == '__main__':
    unittest.main()



import setuptools

setuptools.setup(
    name="commodplot",
    version="1.3.16",
    author="aeorxc",
    author_email="author@example.com",
    description="common commodity plotting including seasonal charts using plotly",
    url="https://github.com/aeorxc/commodplot",
    project_urls={
        'Source': 'https://github.com/aeorxc/commodplot',
    },
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=['pandas', 'plotly', 'commodutil', 'cufflinks'],
    python_requires='>=3.6',
    setup_requires=['pytest-runner'],
    tests_require=['pytest'],
)
